@@ -54,7 +54,7 @@ class {package_name}Conan(Sense2File):
     # channel="beta"
 
     ## upload deb setting
-    apt_user = "qiuhai"
+    apt_user = "user"
     apt_server = "http://10.0.50.109:8081/repository/sense2-system-deb/"
     
     ## set source at the same folder with recipe
@@ -79,7 +79,7 @@ class {package_name}Conan(Sense2File):
         pass
 
     def package(self):
-        self.copy("*.h", dst="include", src="hello")
+        self.copy("*.h", dst="include", src="include")
         self.copy("*.so", dst="lib", keep_path=False)
         self.copy("*.a", dst="lib", keep_path=False)
         self.copy("*", dst="bin", src="bin")
