@@ -4,10 +4,14 @@ import sys
 import signal
 from argparse import ArgumentError
 from conans.client.command import (Command as Command_co, SmartFormatter, OnceArgument, 
+                                    _add_profile_arguments,
                                    _PATH_HELP, _INSTALL_FOLDER_HELP, 
                                    _SOURCE_FOLDER_HELP, _BUILD_FOLDER_HELP, 
                                    _PATTERN_REF_OR_PREF_HELP, _QUERY_HELP)
 from sense2 import __version__ as client_version
+from conans.client.conf.config_installer import is_config_install_scheduled
+from conans.util.log import logger
+from conans.util.files import exception_message_safe
 from sense2.client.sense2_api import Sense2, default_manifest_folder, _make_abs_path, ProfileData
 from conans.errors import ConanException, ConanInvalidConfiguration, NoRemoteAvailable, \
     ConanMigrationError, ConanInvalidSystemRequirements
@@ -423,6 +427,152 @@ class Command(Command_co):
             if args.json and info:
                 self._outputer.json_output(info, args.json, os.getcwd())
 
+    def export_pkg(self, *args):
+        """
+        Exports a recipe, then creates a package from local source and build folders.
+
+        If '--package-folder' is provided it will copy the files from there, otherwise, it
+        will execute package() method over '--source-folder' and '--build-folder' to create
+        the binary package.
+        """
+
+        parser = argparse.ArgumentParser(description=self.export_pkg.__doc__,
+                                         prog="sense2 export-pkg",
+                                         formatter_class=SmartFormatter)
+        parser.add_argument("path", help=_PATH_HELP)
+        parser.add_argument("reference", nargs='?', default=None,
+                            help="user/channel or pkg/version@user/channel "
+                                 "(if name and version are not declared in the "
+                                 "conanfile.py)")
+
+        parser.add_argument("-bf", "--build-folder", action=OnceArgument, help=_BUILD_FOLDER_HELP)
+        parser.add_argument('-f', '--force', default=False, action='store_true',
+                            help='Overwrite existing package if existing')
+        parser.add_argument("-if", "--install-folder", action=OnceArgument,
+                            help=_INSTALL_FOLDER_HELP + " If these files are found in the specified"
+                            " folder and any of '-e', '-o', '-pr' or '-s' arguments are used, it "
+                            "will raise an error.")
+        parser.add_argument("-pf", "--package-folder", action=OnceArgument,
+                            help="folder containing a locally created package. If a value is given,"
+                                 " it won't call the recipe 'package()' method, and will run a copy"
+                                 " of the provided folder.")
+        parser.add_argument("-sf", "--source-folder", action=OnceArgument, help=_SOURCE_FOLDER_HELP)
+        parser.add_argument("-j", "--json", default=None, action=OnceArgument,
+                            help='Path to a json file where the install information will be '
+                            'written')
+        parser.add_argument("-l", "--lockfile", action=OnceArgument,
+                            help="Path to a lockfile.")
+        parser.add_argument("--lockfile-out", action=OnceArgument,
+                            help="Filename of the updated lockfile")
+        parser.add_argument("--ignore-dirty", default=False, action='store_true',
+                            help='When using the "scm" feature with "auto" values, capture the'
+                                 ' revision and url even if there are uncommitted changes')
+        _add_profile_arguments(parser)
+
+        args = parser.parse_args(*args)
+        self._warn_python_version()
+        self._check_lockfile_args(args)
+
+        name, version, user, channel, _ = get_reference_fields(args.reference,
+                                                               user_channel_input=True)
+        cwd = os.getcwd()
+        info = None
+
+        try:
+            profile_build = ProfileData(profiles=args.profile_build, settings=args.settings_build,
+                                        options=args.options_build, env=args.env_build,
+                                        conf=args.conf_build)
+            # TODO: 2.0 create profile_host object here to avoid passing a lot of arguments
+            #       to the API
+
+            info = self._conan.export_pkg(conanfile_path=args.path,
+                                          name=name,
+                                          version=version,
+                                          source_folder=args.source_folder,
+                                          build_folder=args.build_folder,
+                                          package_folder=args.package_folder,
+                                          install_folder=args.install_folder,
+                                          profile_names=args.profile_host,
+                                          env=args.env_host,
+                                          settings=args.settings_host,
+                                          options=args.options_host,
+                                          conf=args.conf_host,
+                                          profile_build=profile_build,
+                                          force=args.force,
+                                          user=user,
+                                          channel=channel,
+                                          lockfile=args.lockfile,
+                                          lockfile_out=args.lockfile_out,
+                                          ignore_dirty=args.ignore_dirty)
+        except ConanException as exc:
+            info = exc.info
+            raise
+        finally:
+            if args.json and info:
+                self._outputer.json_output(info, args.json, cwd)
+
+    def run(self, *args):
+        """HIDDEN: entry point for executing commands, dispatcher to class
+        methods
+        """
+        ret_code = SUCCESS
+        try:
+            try:
+                command = args[0][0]
+            except IndexError:  # No parameters
+                self._show_help()
+                return False
+            try:
+                commands = self._commands()
+                method = commands[command]
+            except KeyError as exc:
+                if command in ["-v", "--version"]:
+                    self._out.success("Sense2 version %s" % client_version)
+                    return False
+
+                self._warn_python_version()
+
+                if command in ["-h", "--help"]:
+                    self._show_help()
+                    return False
+
+                self._out.writeln(
+                    "'%s' is not a Sense2 command. See 'sense2 --help'." % command)
+                self._out.writeln("")
+                self._print_similar(command)
+                raise ConanException("Unknown command %s" % str(exc))
+
+            if (command != "config" or
+               (command == "config" and len(args[0]) > 1 and args[0][1] != "install")) and \
+               is_config_install_scheduled(self._conan):
+                self._conan.config_install(None, None)
+
+            method(args[0][1:])
+        except KeyboardInterrupt as exc:
+            logger.error(exc)
+            ret_code = SUCCESS
+        except SystemExit as exc:
+            if exc.code != 0:
+                logger.error(exc)
+                self._out.error("Exiting with code: %d" % exc.code)
+            ret_code = exc.code
+        except ConanInvalidConfiguration as exc:
+            ret_code = ERROR_INVALID_CONFIGURATION
+            self._out.error(exc)
+        except ConanInvalidSystemRequirements as exc:
+            ret_code = ERROR_INVALID_SYSTEM_REQUIREMENTS
+            self._out.error(exc)
+        except ConanException as exc:
+            ret_code = ERROR_GENERAL
+            self._out.error(exc)
+        except Exception as exc:
+            import traceback
+            print(traceback.format_exc())
+            ret_code = ERROR_GENERAL
+            msg = exception_message_safe(exc)
+            self._out.error(msg)
+
+        return ret_code
 
 def main(args):
     """ main entry point of the conan application, using a Command to
