@@ -122,7 +122,7 @@ def _create_deb_file(conanfile):
     conanfile.run(add_control_cmd)
 
     ## add changelog file
-    assert (not(not conanfile.deb_control)), "deb_changelog is not defined or empty in conanfile.py."
+    assert (not(not conanfile.deb_changelog)), "deb_changelog is not defined or empty in conanfile.py."
     
     changelog_file = debian_folder + "/changelog"
     if os.path.exists(changelog_file):
